**************************
``matplotlib.collections``
**************************

.. inheritance-diagram:: matplotlib.collections
   :parts: 2
   :private-bases:

.. automodule:: matplotlib.collections
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

.. autoclass:: _CollectionWithSizes
   :no-members:
   :members: get_sizes, set_sizes
   :class-doc-from: class

.. autoclass:: _MeshData
   :no-members:
   :members: set_array
   :class-doc-from: class
